@@ -46,7 +46,7 @@ package TinyDNS::Reader;
 
 use TinyDNS::Record;
 
-our $VERSION = '0.7.4';
+our $VERSION = '0.7.5';
 
 
 
@@ -128,12 +128,16 @@ sub parse
     foreach my $line ( split( /[\n\r]/, $self->{ 'data' } ) )
     {
         chomp($line);
+
+        # Skip empty lines.
+        next if ( !$line || !length($line) );
+
+        # Strip trailing comments.
+        $line =~ s/#.*$//s;
+
+        # Skip empty lines.
         next if ( !$line || !length($line) );
 
-        #
-        #  Ignore comments
-        #
-        next if ( $line =~ /^\s*#/ );
 
         #
         #  Ignore "." + ":" records
